developerscripttools.AbjGrepScript
==================================

.. inheritance-diagram:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript
   :private-bases:

.. autoclass:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.alias

.. autoattribute:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.argument_parser

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.formatted_help

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.formatted_usage

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.formatted_version

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.long_description

.. autoattribute:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.program_name

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.scripting_group

.. autoattribute:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.short_description

.. autoattribute:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. autoattribute:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.version

Methods
-------

.. automethod:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.process_args

.. automethod:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.setup_argument_parser

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.__call__

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. automethod:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.AbjGrepScript.AbjGrepScript.AbjGrepScript.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
